==============
A rolling disc
==============

The disc is assumed to be infinitely thin, in contact with the ground at only 1
point, and it is rolling without slip on the ground. See the image below.

.. raw:: html
   :file: rollingdisc.svg

We model the rolling disc in three different ways, to show more of the
functionality of this module.

.. toctree::
    :maxdepth: 1

    rollingdisc_example_kane.rst
    rollingdisc_example_kane_constraints.rst
    rollingdisc_example_lagrange.rst
